cgexplore.optimisation.OMMTrajectory
====================================

.. currentmodule:: cgexplore.optimisation

.. autoclass:: OMMTrajectory
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~OMMTrajectory.get_base_molecule
      ~OMMTrajectory.get_data
      ~OMMTrajectory.yield_conformers
   
   

   
   
   